@@ -3,6 +3,7 @@
 
 #include <string>
 #include "bsondefs.h"
+#include "defs.h"
 
 class BSONObj;
 class BSONArrayObj;
@@ -20,8 +21,8 @@ class BSONParser
 
 	protected:
 	private:
-		static BSONObj* parseBSON(const char* c, int& pos) throw(BSONException);
-		static BSONArrayObj* parseArray(const char* chrs, int& pos);
+		static BSONObj* parseBSON(const char* c, __int32& pos) throw(BSONException);
+		static BSONArrayObj* parseArray(const char* chrs, __int32& pos);
 };
 
 #endif // BSONPARSER_H
